@@ -34,9 +34,12 @@ from vdsm.common import fileutils
 from vdsm.network.link.iface import random_iface_name
 from . import errors as ne
 
-CONF_VOLATILE_RUN_DIR = constants.P_VDSM_RUN + 'netconf/'
-CONF_RUN_DIR = constants.P_VDSM_LIB + 'staging/netconf/'
-CONF_PERSIST_DIR = constants.P_VDSM_LIB + 'persistence/netconf/'
+NETCONF_BONDS = 'bonds'
+NETCONF_NETS = 'nets'
+
+CONF_VOLATILE_RUN_DIR = constants.P_VDSM_RUN + 'netconf'
+CONF_RUN_DIR = constants.P_VDSM_LIB + 'staging/netconf'
+CONF_PERSIST_DIR = constants.P_VDSM_LIB + 'persistence/netconf'
 
 VOLATILE_NET_ATTRS = ('blockingdhcp',)
 
@@ -116,8 +119,9 @@ class BaseConfig(object):
 
 class Config(BaseConfig):
     def __init__(self, savePath):
-        self.networksPath = os.path.join(savePath, 'nets', '')
-        self.bondingsPath = os.path.join(savePath, 'bonds', '')
+        self._netconf_path = savePath
+        self.networksPath = os.path.join(savePath, NETCONF_NETS)
+        self.bondingsPath = os.path.join(savePath, NETCONF_BONDS)
         nets = self._getConfigs(self.networksPath)
         for net_attrs in six.viewvalues(nets):
             _filter_out_volatile_net_attrs(net_attrs)
@@ -130,23 +134,35 @@ class Config(BaseConfig):
         self._clearDisk()
 
     def save(self):
-        self._clearConfigs()
-        for bond, attrs in six.iteritems(self.bonds):
-            self._setConfig(attrs, self._bondingPath(bond))
-        for network, attrs in six.iteritems(self.networks):
-            self._setConfig(attrs, self._networkPath(network))
+        self._clearDisk()
+        rand_suffix = random_iface_name(max_length=8)
+        rand_netconf_path = self._netconf_path + '.' + rand_suffix
+        rand_nets_path = os.path.join(rand_netconf_path, NETCONF_NETS)
+        rand_bonds_path = os.path.join(rand_netconf_path, NETCONF_BONDS)
+
+        self._save_config(self.networks, rand_nets_path)
+        self._save_config(self.bonds, rand_bonds_path)
+
+        _atomic_copytree(
+            rand_netconf_path, self._netconf_path, remove_src=True)
+
         logging.info('Saved new config %r to %s and %s' %
                      (self, self.networksPath, self.bondingsPath))
 
+    def _save_config(self, configs, configpath):
+        os.makedirs(configpath)
+        for configname, attrs in six.iteritems(configs):
+            self._setConfig(attrs, os.path.join(configpath, configname))
+
     def config_exists(self):
         return (os.path.exists(self.networksPath) or
                 os.path.exists(self.bondingsPath))
 
     def _networkPath(self, network):
-        return self.networksPath + network
+        return os.path.join(self.networksPath, network)
 
     def _bondingPath(self, bonding):
-        return self.bondingsPath + bonding
+        return os.path.join(self.bondingsPath, bonding)
 
     @staticmethod
     def _getConfigDict(path):
@@ -168,7 +184,7 @@ class Config(BaseConfig):
         networkEntities = {}
 
         for fileName in os.listdir(path):
-            fullPath = path + fileName
+            fullPath = os.path.join(path, fileName)
             networkEntities[fileName] = Config._getConfigDict(fullPath)
 
         return networkEntities
@@ -184,16 +200,22 @@ class Config(BaseConfig):
         with open(path, 'w') as configurationFile:
             json.dump(config, configurationFile, indent=4)
 
-    def _clearConfigs(self):
-        self._clearDisk()
-        os.makedirs(self.networksPath)
-        os.makedirs(self.bondingsPath)
-
     def _clearDisk(self):
-        logging.info('Clearing %s and %s',
-                     self.networksPath, self.bondingsPath)
-        fileutils.rm_tree(self.networksPath)
-        fileutils.rm_tree(self.bondingsPath)
+        logging.info('Clearing netconf: %s', self._netconf_path)
+        self._clear_config(self._netconf_path)
+
+    @staticmethod
+    def _clear_config(confpath):
+        try:
+            real_confpath = os.path.realpath(confpath)
+            fileutils.rm_file(confpath)
+            fileutils.rm_tree(real_confpath)
+        except OSError as e:
+            # Support the "old" non-symlink config path.
+            if e.errno == errno.EISDIR:
+                fileutils.rm_tree(confpath)
+            else:
+                raise
 
 
 class RunningConfig(Config):
@@ -203,7 +225,14 @@ class RunningConfig(Config):
 
     @staticmethod
     def store():
-        _store_net_config()
+        """
+        Declare the current running config as 'safe' and persist this safe
+        config.
+
+        It is implemented by copying the running config to the
+        persistent (safe) config in an atomic manner.
+        """
+        _atomic_copytree(CONF_RUN_DIR, CONF_PERSIST_DIR)
 
 
 class PersistentConfig(Config):
@@ -261,25 +290,31 @@ def _filter_out_volatile_net_attrs(net_attrs):
         net_attrs.pop(attr, None)
 
 
-def _store_net_config():
+def _atomic_copytree(srcpath, dstpath, remove_src=False):
     """
-    Declare the current running config as 'safe' and persist this safe config.
+    Copy srcpath to dstpatch in an atomic manner.
 
-    It is implemented by copying the running config to the persistent (safe)
-    config in an atomic manner.
     It applies atomic directory copy by using the atomicity of overwriting a
     link (rename syscall).
+
+    In case the remove_src flag argument is True, the srcpath is deleted.
+
+    Note: In case of an interruption, it is assured that the destination is
+    intact, pointing to the previous data or the new one. Intermediate
+    temporary files  or the srcpath may still exists on the filesystem.
     """
-    safeconf_dir = CONF_PERSIST_DIR[:-1]
     rand_suffix = random_iface_name(max_length=8)
-    new_safeconf_dir = safeconf_dir + '.' + rand_suffix
-    new_safeconf_symlink = new_safeconf_dir + '.ln'
+    rand_dstpath = dstpath + '.' + rand_suffix
+    rand_dstpath_symlink = rand_dstpath + '.ln'
 
-    shutil.copytree(CONF_RUN_DIR[:-1], new_safeconf_dir)
-    os.symlink(new_safeconf_dir, new_safeconf_symlink)
+    shutil.copytree(srcpath, rand_dstpath)
+    os.symlink(rand_dstpath, rand_dstpath_symlink)
 
-    real_old_safeconf_dir = os.path.realpath(safeconf_dir)
-    os.rename(new_safeconf_symlink, safeconf_dir)
-    real_old_safeconf_dir_existed = real_old_safeconf_dir != safeconf_dir
-    if real_old_safeconf_dir_existed:
-        fileutils.rm_tree(real_old_safeconf_dir)
+    old_realdstpath = os.path.realpath(dstpath)
+    old_realdstpath_existed = old_realdstpath != dstpath
+
+    os.rename(rand_dstpath_symlink, dstpath)
+    if old_realdstpath_existed:
+        fileutils.rm_tree(old_realdstpath)
+    if remove_src:
+        fileutils.rm_tree(srcpath)
