@@ -55,6 +55,9 @@ log = logging.getLogger('storage.Volume')
 
 class BlockVolumeManifest(volume.VolumeManifest):
 
+    # How this volume is presented to a vm.
+    DISK_TYPE = "block"
+
     # On block storage volume are composed of lvm extents, 128m by default.
     align_size = sc.VG_EXTENT_SIZE_MB * constants.MEGAB
 
