@@ -24,8 +24,8 @@ import os
 from libvirt import libvirtError, VIR_ERR_NO_NETWORK
 
 from vdsm.common import commands
+from vdsm.common import libvirtconnection
 from vdsm.network.api import DUMMY_BRIDGE
-from .. import libvirtconnection
 from . import expose, ExtraArgsError
 
 EXT_BRCTL = '/usr/sbin/brctl'
