@@ -26,10 +26,10 @@ from testValidation import broken_on_ci
 from testlib import VdsmTestCase
 
 from .nettestlib import dummy_device, dummy_devices, preserve_default_route
+from .nettestlib import requires_nm_stopped
 
 from vdsm.network.ip import address
 from vdsm.network.netinfo import routes
-from vdsm.network.netlink import waitfor
 
 
 DEVICE_NAME = 'foo'
@@ -222,6 +222,7 @@ class IPAddressTest(VdsmTestCase):
         self._test_add_delete(IPV6_A_WITH_PREFIXLEN, IPV6_B_WITH_PREFIXLEN)
 
     @broken_on_ci("IPv6 not supported on travis", name="TRAVIS_CI")
+    @requires_nm_stopped('Fails randomly when NM is running. See BZ#1512316')
     def test_add_delete_ipv4_ipv6(self):
         self._test_add_delete(IPV4_A_WITH_PREFIXLEN, IPV6_B_WITH_PREFIXLEN)
 
@@ -237,11 +238,11 @@ class IPAddressTest(VdsmTestCase):
             self._assert_has_address(nic, ip_a)
             self._assert_has_address(nic, ip_b)
 
-            self._ipaddress_delete(ip_b_data)
+            IPAddressTest.IPAddress.delete(ip_b_data)
             self._assert_has_address(nic, ip_a)
             self._assert_has_no_address(nic, ip_b)
 
-            self._ipaddress_delete(ip_a_data)
+            IPAddressTest.IPAddress.delete(ip_a_data)
             self._assert_has_no_address(nic, ip_a)
             self._assert_has_no_address(nic, ip_b)
 
@@ -345,11 +346,3 @@ class IPAddressTest(VdsmTestCase):
     def _assert_address_not_in(self, address_with_prefixlen, addresses):
         addresses_list = [addr.address_with_prefixlen for addr in addresses]
         self.assertNotIn(address_with_prefixlen, addresses_list)
-
-    def _ipaddress_delete(self, address_data):
-        """ Blocking version of IP address delete """
-        with waitfor.waitfor_ip_addr(address_data.device,
-                                     address_data.address_with_prefixlen,
-                                     action='del_addr',
-                                     timeout=0.5):
-            IPAddressTest.IPAddress.delete(address_data)
