@@ -20,7 +20,6 @@
 
 from __future__ import print_function
 import copy
-import gc
 import logging
 import os
 import os.path
@@ -696,58 +695,3 @@ class TestStopwatch(TestCaseBase):
         with utils.stopwatch("message", level=logging.INFO, log=log):
             pass
         self.assertNotEqual(log.messages, [])
-
-
-class ObjectWithDel(object):
-
-    def public(self, *args, **kw):
-        return 'public', args, kw
-
-    def __del__(self):
-        print('__del__', self.__class__.__name__)
-
-
-class TestWeakmethod(TestCaseBase):
-
-    def setUp(self):
-        self.saved_flags = gc.get_debug()
-        gc.disable()
-        gc.set_debug(0)
-
-    def tearDown(self):
-        gc.collect()
-        for obj in gc.garbage:
-            if type(obj) is ObjectWithDel:
-                obj.public = None
-                gc.garbage.remove(obj)
-        gc.set_debug(self.saved_flags)
-        gc.enable()
-
-    def test_with_reference_cycle(self):
-        def _leaking_wrapper(meth):
-            def wrapper(*args, **kwargs):
-                return meth(*args, **kwargs)
-            return wrapper
-
-        obj = ObjectWithDel()
-        obj.public = _leaking_wrapper(obj.public)
-        self.assertEqual(obj.public(), ("public", (), {}))
-        del obj
-        gc.collect()
-        self.assertIn(ObjectWithDel, [type(obj) for obj in gc.garbage])
-
-    def test_without_reference_cycle(self):
-        obj = ObjectWithDel()
-        obj.public = utils.weakmethod(obj.public)
-        self.assertEqual(obj.public(), ("public", (), {}))
-        del obj
-        gc.collect()
-        self.assertNotIn(ObjectWithDel, [type(obj) for obj in gc.garbage])
-
-    def test_raise_on_invalid_weakref(self):
-        obj = ObjectWithDel()
-        method = utils.weakmethod(obj.public)
-        obj.public = method
-        self.assertEqual(obj.public(), ("public", (), {}))
-        del obj
-        self.assertRaises(utils.InvalidatedWeakRef, method)
